==> 0.0.28.tar.gz: macos/Classes/AssistivePlugin.swift <==
import Cocoa
import FlutterMacOS
import Foundation

public class AssistivePlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "plugins.flutter.io/assistive_plugin", binaryMessenger: registrar.messenger)
    let instance = AssistivePlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
    case "getPlatformVersion":
      result("macOS " + ProcessInfo.processInfo.operatingSystemVersionString)
    case "checkForAssibility":
      result(checkForAssibilityPermission())
    case "takeScreenShot":
      result(takeScreenShotWindow())
    default:
      result(FlutterMethodNotImplemented)
    }
  }
}

private func takeScreenShotWindow() -> NSString {
   /* var displayCount: UInt32 = 0;
   var result = CGGetActiveDisplayList(0, nil, &displayCount)
   if (result != CGError.success) {
       print("error: \(result)")
       return false
   }
   let allocated = Int(displayCount)
   let activeDisplays = UnsafeMutablePointer<CGDirectDisplayID>.allocate(capacity: allocated)
   result = CGGetActiveDisplayList(displayCount, activeDisplays, &displayCount)

   if (result != CGError.success) {
       print("error: \(result)")
       return false
   }

   for i in 1...displayCount {
       let unixTimestamp = CreateTimeStamp()
       let fileUrl = URL(fileURLWithPath: "Users/arslanhabib/Desktop/" + "\(unixTimestamp)" + "_" + "\(i)" + ".jpg", isDirectory: true)
       let screenShot:CGImage = CGDisplayCreateImage(activeDisplays[Int(i-1)])!
       let bitmapRep = NSBitmapImageRep(cgImage: screenShot)
       let jpegData = bitmapRep.representation(using: NSBitmapImageRep.FileType.jpeg, properties: [:])!

        do {
            try jpegData.write(to: fileUrl, options: .atomic)
        }
        catch {print("error: \(error)")}
    }
   return true; */
   let displayID = CGMainDisplayID()
   let imageRef = CGDisplayCreateImage(displayID)
   return imageRef
}

func CreateTimeStamp() -> Int32
{
    return Int32(Date().timeIntervalSince1970)
}

private func checkForAssibilityPermission() -> Bool {
    let allow = AXIsProcessTrusted();
    if(allow){
    return true;
    }else{
    /* let script = NSAppleScript(source: "tell application \"System Preferences\"
                                            activate
                                            set current pane to pane \"com.apple.preferences.users\"
                                            delay 2
                                            tell application \"System Events\"
                                                click radio button \"Login Items\" of tab group 1 of window \"Users & Groups\" of application process \"System Preferences\"
                                            end tell
                                        end tell")!
    var errorDict : NSDictionary?
    script.executeAndReturnError(&errorDict) */
       NSWorkspace.shared.open(URL(fileURLWithPath: "x-apple.systempreferences:com.apple.preference.security?Privacy_Accessibility"));
//        let options : NSDictionary = [kAXTrustedCheckOptionPrompt.takeRetainedValue() as NSString: true]
//        let accessibilityEnabled = AXIsProcessTrustedWithOptions(options)
    }
    return false;
}

==> 0.0.32.tar.gz: macos/Classes/AssistivePlugin.swift <==
import Cocoa
import FlutterMacOS
import Foundation

public class AssistivePlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "plugins.flutter.io/assistive_plugin", binaryMessenger: registrar.messenger)
    let instance = AssistivePlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
    case "getPlatformVersion":
      result("macOS " + ProcessInfo.processInfo.operatingSystemVersionString)
    case "checkForAssibility":
      result(checkForAssibilityPermission())
    case "takeScreenShot":
      result(takeScreenShotWindow())
    default:
      result(FlutterMethodNotImplemented)
    }
  }
}

private func takeScreenShotWindow() -> CGImage {
   /* var displayCount: UInt32 = 0;
   var result = CGGetActiveDisplayList(0, nil, &displayCount)
   if (result != CGError.success) {
       print("error: \(result)")
       return false
   }
   let allocated = Int(displayCount)
   let activeDisplays = UnsafeMutablePointer<CGDirectDisplayID>.allocate(capacity: allocated)
   result = CGGetActiveDisplayList(displayCount, activeDisplays, &displayCount)

   if (result != CGError.success) {
       print("error: \(result)")
       return false
   }

   for i in 1...displayCount {
       let unixTimestamp = CreateTimeStamp()
       let fileUrl = URL(fileURLWithPath: "Users/arslanhabib/Desktop/" + "\(unixTimestamp)" + "_" + "\(i)" + ".jpg", isDirectory: true)
       let screenShot:CGImage = CGDisplayCreateImage(activeDisplays[Int(i-1)])!
       let bitmapRep = NSBitmapImageRep(cgImage: screenShot)
       let jpegData = bitmapRep.representation(using: NSBitmapImageRep.FileType.jpeg, properties: [:])!

        do {
            try jpegData.write(to: fileUrl, options: .atomic)
        }
        catch {print("error: \(error)")}
    }
   return true; */
   let displayID = CGMainDisplayID()
   let imageRef = CGDisplayCreateImage(displayID)

   return imageRef
}

func CreateTimeStamp() -> Int32
{
    return Int32(Date().timeIntervalSince1970)
}

private func checkForAssibilityPermission() -> Bool {
    let allow = AXIsProcessTrusted();
    if(allow){
    return true;
    }else{
    /* let script = NSAppleScript(source: "tell application \"System Preferences\"
                                            activate
                                            set current pane to pane \"com.apple.preferences.users\"
                                            delay 2
                                            tell application \"System Events\"
                                                click radio button \"Login Items\" of tab group 1 of window \"Users & Groups\" of application process \"System Preferences\"
                                            end tell
                                        end tell")!
    var errorDict : NSDictionary?
    script.executeAndReturnError(&errorDict) */
       NSWorkspace.shared.open(URL(fileURLWithPath: "x-apple.systempreferences:com.apple.preference.security?Privacy_Accessibility"));
//        let options : NSDictionary = [kAXTrustedCheckOptionPrompt.takeRetainedValue() as NSString: true]
//        let accessibilityEnabled = AXIsProcessTrustedWithOptions(options)
    }
    return false;
}
